Learn R Programming

vDiveR (version 2.1.0)

concat_conserved_kmer: k-mer sequences concatenation

Description

This function concatenates completely ( index incidence = 100% ) only or both both the completely and highly ( 90% <= index incidence < 100% ) conserved k-mer positions that overlapped at least one k-mer position or are adjacent to each other and generate the CCS/HCS sequence in either CSV or FASTA format

Usage

concat_conserved_kmer(
  data,
  conservation_level = "HCS",
  kmer = 9,
  threshold_pct = NULL
)

Value

A list wit csv and fasta dataframes

Arguments

data

DiMA JSON converted csv file data

conservation_level

CCS (completely conserved) / HCS (highly conserved)

kmer

size of the k-mer window

threshold_pct

manually set threshold of index.incidence for HCS

Examples

Run this code
csv<-concat_conserved_kmer(proteins_1host)$csv
csv_2hosts<-concat_conserved_kmer(protein_2hosts, conservation_level = "CCS")$csv
fasta <- concat_conserved_kmer(protein_2hosts, conservation_level = "HCS")$fasta

Run the code above in your browser using DataLab